// bytran -|- spectral calculations for portable devices using the HITRAN database
//
// Developed by Dzianis Pliutau (Denis Plutov) and Kostya Roslyakov
// www.bytran.org | contact@bytran.org
// Copyright (c) 2016 Dzianis Pliutau
// Distributed under the MIT license
//
// The MIT License (MIT)
// Copyright (c) 2016 Dzianis Pliutau
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation
// files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy,
// modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software
// is furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
// OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR
// IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.



// QML component to notify the user of the current activities
import QtQuick 2.7
import QtQuick.Controls 2.0
import QtQuick.Layouts 1.0

// This component is used in order to notify user of the events taking place in the program
// such as the download of the HITRAN database, line-by-line calculation and the like

Item {

    id: notifierItem
    anchors.fill: parent
    visible: notifyObj.visible

    // Rectangle to draw the form border
    Rectangle {
        id: borderRect
        anchors.fill: notifierColumnLayout
        anchors.margins: coreObj.defaultLabelHeight * (-0.85)
        anchors.bottomMargin: cancelButton.visible ? coreObj.defaultLabelHeight * (-0.5) : coreObj.defaultLabelHeight * (-1)
        color: "white"
        border.width: 1
        border.color: "gray"
        radius: coreObj.defaultLabelHeight * 0.5
    }

    // Qml component is used in order to notify the user about ongoing events
    ColumnLayout {

        id: notifierColumnLayout
        anchors.centerIn: parent

        // Label to display the notification
        CustomLabel {
            id: descriptionLabel
            text: notifyObj.notification
        }

        // Progress bar to display the progress
        ProgressBar {
            id: progressBar
            //Layout.fillWidth: true
            value: notifyObj.value            
            indeterminate: notifyObj.indeterminate
            implicitWidth: descriptionLabel.width
        }

        // Button to cancel the current operation
        CustomButton {
            id: cancelButton
            anchors.right: progressBar.right
            anchors.left: progressBar.left
            anchors.top: progressBar.bottom
            implicitHeight: cancelButtonText.height * 1.9
            visible: notifyObj.cancelButtonVisible
            opacity: 0.5

            CustomText {
                id: cancelButtonText
                anchors.centerIn: parent
                color: 'black'                
                text: qsTr("Cancel")
            }            

            // Canceling the calculation when the cancel button is pressed
            onClicked: {
                    coreObj.cancelCalculation();  // Canceling the operation
            }
        }
    }
}
