// bytran -|- spectral calculations for portable devices using the HITRAN database
//
// Developed by Dzianis Pliutau (Denis Plutov) and Kostya Roslyakov
// www.bytran.org | contact@bytran.org
// Copyright (c) 2016 Dzianis Pliutau
// Distributed under the MIT license
//
// The MIT License (MIT)
// Copyright (c) 2016 Dzianis Pliutau
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation
// files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy,
// modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software
// is furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
// OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR
// IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.



// QML component with the cumulative sensors information
import QtQuick 2.7
import QtQuick.Controls 2.0
import QtQuick.Layouts 1.0
import QtQuick.Window 2.2

Item {

    id: sensorsItem
    anchors.fill: parent

    // When the screen is rotated adjusting the position and orientation of the button used to search for phones with sensors
    onHeightChanged:
    {
        if (Screen.primaryOrientation === Qt.PortraitOrientation)
        {
            searchPhonesBorderRect.rotation = 0
            searchPhones.rotation = 0
            searchPhones.anchors.topMargin = 0
            searchPhones.anchors.leftMargin = 0
        }
        else
        {
            searchPhonesBorderRect.rotation = 270
            searchPhones.rotation = 270
            searchPhones.anchors.topMargin = - 0.5 * searchPhones.width - 0.5 * searchPhones.height - coreObj.defaultLabelHeight * 0.85
            searchPhones.anchors.leftMargin = - 0.5 * searchPhones.width - 0.5 * searchPhones.height - coreObj.defaultLabelHeight * 0.85
        }
    }

    // Rectangle to shade the background
    Rectangle {
        anchors.fill: parent
        border.width: 1
        border.color: 'black'
        color: Qt.rgba(0, 0, 0, 0.6)

        // This is introduced to disable items located on the background
        MouseArea {
            anchors.fill: parent
            onClicked: { }
        }
    }

    // Rectangle to draw the form border
    Rectangle {
        id: formBorderRect
        anchors.fill: mainSensorsColumnLayout
        anchors.margins: coreObj.defaultLabelHeight * (-0.85)
        color: "white"
        border.width: 1
        border.color: 'gray'
        radius: coreObj.defaultLabelHeight * 0.5
    }

    // Exit button
    CustomButton {
        id: exitButton
        anchors.top: sensorsItem.top
        anchors.right: sensorsItem.right
        anchors.margins: coreObj.defaultLabelHeight * (0.1)
        implicitWidth: 1.5 * exitButton.height
        text: qsTr("X")
        onClicked: sensorsItem.destroy()
    }

    Rectangle {
        id: searchPhonesBorderRect
        anchors.fill: searchPhones
        anchors.margins: coreObj.defaultLabelHeight * (-0.85) + 1
        color: "white"
        border.width: 1
        border.color: 'white'
        radius: coreObj.defaultLabelHeight * 0.5
    }
    CustomDialogButtonWithBackground {
        id: searchPhones
        anchors.top: formBorderRect.bottom
        anchors.left: mainSensorsColumnLayout.left
        text: qsTr("  Phone to use?  ")
        onClicked: { aboutDataObj.searchPhoneWithSensors() }        
    }

    ColumnLayout {
        id: mainSensorsColumnLayout
        anchors.centerIn: parent

        CustomLabel {
            id: commentLabel
            text: qsTr("Sensor data may be used or manual input")
        }

        GridLayout {            

            // Changing the total pressure value
            CustomLabel {
                id: samplingPeriodLabel
                anchors.right: samplingFrequencyTextField.left
                anchors.rightMargin: coreObj.defaultLabelHeight * 0.5
                Layout.column: 0
                Layout.row: 0
                horizontalAlignment: Text.AlignRight
                text: qsTr("Sampling period\n(milliseconds):")
            }
            CustomTextField {
                id: samplingPeriodTextField
                Layout.column: 1
                Layout.row: 0
                implicitWidth: (sensorsDataObj.humiditySensorIsPresent() || sensorsDataObj.temperatureSensorIsPresent() || sensorsDataObj.totalPressureSensorIsPresent()) ? useTotalPressureSensorSwitchRowLayout.width : (commentLabel.width - samplingPeriodLabel.width)
                text: sensorsDataObj.samplingPeriod
                onTextChanged: sensorsDataObj.samplingPeriod = text
            }

            // Changing the wavelength range
            CustomLabel {
                id: samplesToAverageLabel
                anchors.right: samplesToAverageTextField.left
                anchors.rightMargin: coreObj.defaultLabelHeight * 0.5
                Layout.column: 0
                Layout.row: 1
                horizontalAlignment: Text.AlignRight
                text: qsTr("Samples to\naverage:")
            }
            CustomTextField {
                id: samplesToAverageTextField
                Layout.column: 1
                Layout.row: 1
                implicitWidth:  (sensorsDataObj.humiditySensorIsPresent() || sensorsDataObj.temperatureSensorIsPresent() || sensorsDataObj.totalPressureSensorIsPresent()) ? useTotalPressureSensorSwitchRowLayout.width : (commentLabel.width - samplingPeriodLabel.width)
                text: sensorsDataObj.numSamplesToAverage
                onTextChanged: sensorsDataObj.numSamplesToAverage = text
            }

            // Emailing the results of the calculations (the plot, data or both)
            CustomLabel {
                id: averagingTimeLabel
                anchors.right: averagingTimeValueLabel.left
                anchors.rightMargin: coreObj.defaultLabelHeight * 0.4
                Layout.column: 0
                Layout.row: 2
                horizontalAlignment: Text.AlignRight
                text: qsTr("Averaging time:")
            }
            CustomLabel {
                id: averagingTimeValueLabel
                Layout.column: 1
                Layout.row: 2
                color: 'red'
                text: sensorsDataObj.averagingTime + "  milliseconds"
            }

            Rectangle {
                id: separatorRect
                Layout.fillWidth: true
                Layout.column: 0
                Layout.row: 3
                height: 1
                color: '#C0C0C0'
            }

            Rectangle {
                id: separator2Rect
                Layout.fillWidth: true
                Layout.column: 1
                Layout.row: 3
                height: 1
                color: '#C0C0C0'
            }

            // Enabling data from barometer instead of manual values
            CustomLabel {
                id: useHumiditySensorLabel
                anchors.right: sensorsDataObj.humiditySensorIsPresent() ? useHumiditySensorSwitchRowLayout.left : useHumiditySensorUnavailLabel.left
                anchors.rightMargin: coreObj.defaultLabelHeight * 0.4
                Layout.column: 0
                Layout.row: 4
                horizontalAlignment: Text.AlignRight
                text: sensorsDataObj.humiditySensorIsPresent() ? qsTr("Humidity sensor:\n" + sensorsDataObj.humidity) : qsTr("Humidity sensor:")
            }            
            CustomLabel {
                id: useHumiditySensorUnavailLabel
                Layout.column: 1
                Layout.row: 4
                visible: !sensorsDataObj.humiditySensorIsPresent()
                color: 'gray'
                text: sensorsDataObj.humiditySensorIsSupported() ? qsTr(" None detected in device") : qsTr(" Not supported")
            }
            RowLayout {
                id: useHumiditySensorSwitchRowLayout
                Layout.column: 1
                Layout.row: 4
                visible: sensorsDataObj.humiditySensorIsPresent()

                CustomLabel {
                    id: onHumidityRowLabel
                    anchors.right: useHumiditySensorSwitch.left
                    text: qsTr("Manual\nentry")
                    color: 'gray'
                    MouseArea {
                        anchors.fill: parent
                        onClicked: useHumiditySensorSwitch.checked = false
                    }
                }
                CustomSwitch {
                    id: useHumiditySensorSwitch
                    anchors.centerIn: parent
                    padding: 0
                    topPadding: coreObj.defaultLabelHeight * 0.4
                    bottomPadding: coreObj.defaultLabelHeight * 0.1
                    checked: sensorsDataObj.humiditySensorEnabled
                    onCheckedChanged: sensorsDataObj.humiditySensorEnabled = checked
                }
                CustomLabel {
                    id: offHumidityRowLabel
                    anchors.left: useHumiditySensorSwitch.right
                    text: qsTr("Use\nsensor");
                    color: 'black'
                    MouseArea {
                        anchors.fill: parent
                        onClicked: useHumiditySensorSwitch.checked = true
                    }
                }
            }

            // Enabling data from barometer instead of manual values
            CustomLabel {
                id: useTotalPressureSensorLabel
                anchors.right: sensorsDataObj.totalPressureSensorIsPresent() ? useTotalPressureSensorSwitchRowLayout.left : useTotalPressureSensorUnavailLabel.left
                anchors.rightMargin: coreObj.defaultLabelHeight * 0.4
                Layout.column: 0
                Layout.row: 5
                horizontalAlignment: Text.AlignRight
                text: sensorsDataObj.totalPressureSensorIsPresent() ? qsTr("Barometer:\n" + sensorsDataObj.totalPressure) : qsTr("Barometer:")
            }
            CustomLabel {
                id: useTotalPressureSensorUnavailLabel
                Layout.column: 1
                Layout.row: 5
                visible: !sensorsDataObj.totalPressureSensorIsPresent()
                color: 'gray'
                text: qsTr(" None detected in device")
            }
            RowLayout {
                id: useTotalPressureSensorSwitchRowLayout
                Layout.column: 1
                Layout.row: 5
                visible: sensorsDataObj.totalPressureSensorIsPresent()

                CustomLabel {
                    id: onTotalPressureRowLabel
                    anchors.right: useTotalPressureSensorSwitch.left
                    text: qsTr("Manual\nentry")
                    color: 'gray'
                    MouseArea {
                        anchors.fill: parent
                        onClicked: useTotalPressureSensorSwitch.checked = false
                    }
                }
                CustomSwitch {
                    id: useTotalPressureSensorSwitch
                    anchors.centerIn: parent
                    padding: 0
                    topPadding: coreObj.defaultLabelHeight * 0.4
                    bottomPadding: coreObj.defaultLabelHeight * 0.1
                    checked: sensorsDataObj.totalPressureSensorEnabled
                    onCheckedChanged: sensorsDataObj.totalPressureSensorEnabled = checked
                }
                CustomLabel {
                    id: offTotalPressureRowLabel
                    anchors.left: useTotalPressureSensorSwitch.right
                    text: qsTr("Use\nsensor");
                    color: 'black'
                    MouseArea {
                        anchors.fill: parent
                        onClicked: useTotalPressureSensorSwitch.checked = true
                    }
                }
            }

            // Enabling data from barometer instead of manual values
            CustomLabel {
                id: useTemperatureSensorLabel
                anchors.right: sensorsDataObj.temperatureSensorIsPresent() ? useTemperatureSensorSwitchRowLayout.left : useTemperatureSensorUnavailLabel.left
                anchors.rightMargin: coreObj.defaultLabelHeight * 0.4
                Layout.column: 0
                Layout.row: 6
                horizontalAlignment: Text.AlignRight
                text: sensorsDataObj.temperatureSensorIsPresent() ? qsTr("Thermometer:\n" + sensorsDataObj.temperature) : qsTr("Thermometer:")
            }            
            CustomLabel {
                id: useTemperatureSensorUnavailLabel
                Layout.column: 1
                Layout.row: 6
                visible: !sensorsDataObj.temperatureSensorIsPresent()
                color: 'gray'
                text: qsTr(" None detected in device")
            }
            RowLayout {
                id: useTemperatureSensorSwitchRowLayout
                Layout.column: 1
                Layout.row: 6
                visible: sensorsDataObj.temperatureSensorIsPresent()

                CustomLabel {
                    id: onTemperatureRowLabel
                    anchors.right: useTemperatureSensorSwitch.left
                    text: qsTr("Manual\nentry")
                    color: 'gray'
                    MouseArea {
                        anchors.fill: parent
                        onClicked: useTemperatureSensorSwitch.checked = false
                    }
                }
                CustomSwitch {
                    id: useTemperatureSensorSwitch
                    anchors.centerIn: parent
                    padding: 0
                    topPadding: coreObj.defaultLabelHeight * 0.4
                    bottomPadding: coreObj.defaultLabelHeight * 0.1
                    checked: sensorsDataObj.temperatureSensorEnabled
                    onCheckedChanged: sensorsDataObj.temperatureSensorEnabled = checked
                }
                CustomLabel {
                    id: offTemperatureRowLabel
                    anchors.left: useTemperatureSensorSwitch.right
                    text: qsTr("Use\nsensor");
                    color: 'black'
                    MouseArea {
                        anchors.fill: parent
                        onClicked: useTemperatureSensorSwitch.checked = true
                    }
                }
            }
        }
    }
}
