// bytran -|- spectral calculations for portable devices using the HITRAN database
//
// Developed by Dzianis Pliutau (Denis Plutov) and Kostya Roslyakov
// www.bytran.org | contact@bytran.org
// Copyright (c) 2016 Dzianis Pliutau
// Distributed under the MIT license
//
// The MIT License (MIT)
// Copyright (c) 2016 Dzianis Pliutau
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation
// files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy,
// modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software
// is furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
// OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR
// IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.



// QML component to select the way the results are to be shared (SMS or email and so on)
import QtQuick 2.7
import QtQuick.Controls 2.0
import QtQuick.Layouts 1.0

Item {

    id: shareResultsChoiceItem
    anchors.fill: parent    

    // Rectangle to shade the background
    Rectangle {
        anchors.fill: parent
        border.width: 1
        border.color: 'black'
        color: Qt.rgba(0, 0, 0, 0.6)

        // This is introduced to disable items located on the background
        MouseArea {
            anchors.fill: parent
            onClicked: { }
        }
    }

    // Rectangle to draw the form border
    Rectangle {
        anchors.fill: shareColumnLayout
        anchors.margins: coreObj.defaultLabelHeight * (-0.85)
        color: "white"
        border.width: 1
        border.color: 'gray'
        radius: coreObj.defaultLabelHeight * 0.5
    }

    CustomLabel {
        id: heightLabel
        text: "The results of the calculations may"
        visible: false
        enabled: false
    }

    // Exit button
    CustomButton {
        id: exitButton
        anchors.top: shareResultsChoiceItem.top
        anchors.right: shareResultsChoiceItem.right
        anchors.margins: coreObj.defaultLabelHeight * (0.1)
        implicitWidth: 1.5 * exitButton.height
        text: qsTr("X")
        onClicked: shareResultsChoiceItem.destroy()
    }

    ColumnLayout {
        id: shareColumnLayout
        anchors.centerIn: parent
        anchors.bottom: infoLabel.bottom

        CustomLabel {
            id: winrtCommentLabel
            Layout.fillWidth: true
            text: qsTr("Note: This capability is currently\nnot available for Windows phones")
            color: 'blue'
            visible: ((Qt.platform.os == 'winrt') || (Qt.platform.os == 'winphone')) ? true : false
        }

        CustomLabel {
            id: commentLabel
            Layout.fillWidth: true           
            text: qsTr("The results of the calculations may\nbe shared and/or stored as follows:")
            visible: ((Qt.platform.os == 'winrt') || (Qt.platform.os == 'winphone')) ? false : true
        }

        // Sharing the results of the calculations
        CustomButtonWithBackground {
            id: shareButton           
            Layout.fillWidth: true            
            text: qsTr("Share results")
            enabled: ((Qt.platform.os == 'winrt') || (Qt.platform.os == 'winphone')) ? false : true

            // Sharing the results of the calculations
            onClicked: {
                if (shareResultsDataObj.dataAvailable)
                {
                    shareResultsDataObj.shareResults = true;
                    shareResultsDataObj.saveToDocuments();
                    var component = Qt.createComponent("Notifier.qml")
                    if (component.status === Component.Ready)
                    {
                        shareResultsNotifierWindow = component.createObject(shareResultsChoiceItem)
                    }
                    shareResultsNotifierWindow.show()
                }
                else
                {
                    shareResultsDataObj.showNoDataAlert()
                }
            }
        }

        Rectangle {
            id: spacerRectangle1
            Layout.fillWidth: true
            height: 1
            color: 'transparent'
            visible: ((Qt.platform.os == 'winrt') || (Qt.platform.os == 'winphone')) ? true : false
        }

        CustomCheckBox {
            id: attachImageCheckBox
            Layout.fillWidth: true            
            checked: shareResultsDataObj.attachImage
            onCheckedChanged: shareResultsDataObj.attachImage = checked
            text: (Qt.platform.os == 'ios') ? qsTr("Attach image to message") : qsTr(" Attach image to message")
            enabled: ((Qt.platform.os == 'winrt') || (Qt.platform.os == 'winphone')) ? false : true
        }

        CustomCheckBox {
            id: attachDataCheckBox
            Layout.fillWidth: true
            topPadding: 0
            checked: shareResultsDataObj.attachDataFile
            onCheckedChanged: shareResultsDataObj.attachDataFile = checked
            text: (Qt.platform.os == 'ios') ? qsTr("Attach data file to message") : qsTr(" Attach data file to message")
            enabled: ((Qt.platform.os == 'winrt') || (Qt.platform.os == 'winphone')) ? false : true
        }

        Rectangle {
            id: separatorRectangle
            Layout.fillWidth: true
            height: 1
            color: '#D3D3D3'
        }

        CustomLabel {
            id: infoLabel
            Layout.fillWidth: true
            horizontalAlignment: Text.AlignCenter
            text: {
                if (coreObj.externalStorageAccessGranted) { return qsTr("The image and data will be saved to\n\"Documents/bytran\" folder") }
                else { return qsTr("The image and data will be saved to\nthe hidden application folder.") }
            }
        }

        // Saving data to documents
        CustomButtonWithBackground {
            id: saveToDocumentsButton            
            Layout.fillWidth: true            
            text: qsTr("   Save to Documents   ")
            enabled: ((Qt.platform.os == 'winrt') || (Qt.platform.os == 'winphone')) ? false : true

            // Saving all generated data to documents
            onClicked: {
                if (shareResultsDataObj.dataAvailable)
                {
                    shareResultsDataObj.saveToDocuments();
                    var component = Qt.createComponent("Notifier.qml")
                    if (component.status === Component.Ready)
                    {
                        shareResultsNotifierWindow = component.createObject(shareResultsChoiceItem)
                    }
                    shareResultsNotifierWindow.show()
                }
                else
                {
                    shareResultsDataObj.showNoDataAlert()
                }
            }
        }
    }
}
