// bytran -|- spectral calculations for portable devices using the HITRAN database
//
// Developed by Dzianis Pliutau (Denis Plutov) and Kostya Roslyakov
// www.bytran.org | contact@bytran.org
// Copyright (c) 2016 Dzianis Pliutau
// Distributed under the MIT license
//
// The MIT License (MIT)
// Copyright (c) 2016 Dzianis Pliutau
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation
// files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy,
// modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software
// is furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
// OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR
// IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.



// QML component is used to specify the gas temperature to be used in calculations
import QtQuick 2.7
import QtQuick.Controls 2.0
import QtQuick.Layouts 1.0

Item {

    id: temperatureItem
    anchors.fill: parent

    // Rectangle to shade the background
    Rectangle {
        anchors.fill: parent
        border.width: 1
        border.color: 'black'
        color: Qt.rgba(0, 0, 0, 0.6)

        // This is introduced to disable items located on the background
        MouseArea {
            anchors.fill: parent
            onClicked: { }
        }
    }

    // Rectangle to draw the form border
    Rectangle {
        anchors.fill: mainTemperatureColumnLayout
        anchors.margins: coreObj.defaultLabelHeight * (-0.85)
        color: "white"
        border.width: 1
        border.color: 'gray'
        radius: coreObj.defaultLabelHeight * 0.5
    }

    // Exit button
    CustomButton {
        id: exitButton
        anchors.top: temperatureItem.top
        anchors.right: temperatureItem.right
        anchors.margins: coreObj.defaultLabelHeight * (0.1)
        implicitWidth: 1.5 * exitButton.height
        text: qsTr("X")
        onClicked: temperatureItem.destroy()
    }

    CustomLabel {
        id: widthLabel
        text: "Gas mixture temperature units and value"
        visible: false
        enabled: false
    }

    // Column layout to hold all the interface items
    ColumnLayout {
        // At rotation the buttons are not positioned exactly the way they should be (fix this)
        id: mainTemperatureColumnLayout
        anchors.centerIn: parent
        spacing: 5
        transformOrigin: Item.Center
        Layout.fillWidth: true
        Layout.fillHeight: true
        CustomLabel {
            Layout.fillWidth: true
            id: commentLabel
            text: qsTr("Gas mixture temperature units and value")
        }

        GridLayout {

            // Enabling data from barometer instead of manual values
            CustomLabel {
                id: useSensorLabel
                anchors.right: useSensorSwitchRowLayout.left
                anchors.rightMargin: coreObj.defaultLabelHeight * 0.4
                Layout.column: 0
                Layout.row: 0
                horizontalAlignment: Text.AlignRight
                visible: sensorsDataObj.temperatureSensorIsPresent()
                text: qsTr("Value to use:")
            }
            RowLayout {
                id: useSensorSwitchRowLayout
                Layout.column: 1
                Layout.row: 0
                visible: sensorsDataObj.temperatureSensorIsPresent()

                CustomLabel {
                    id: onRowLabel
                    anchors.right: useSensorSwitch.left
                    text: qsTr("Manual\nentry")
                    color: 'gray'
                    MouseArea {
                        anchors.fill: parent
                        onClicked: useSensorSwitch.checked = false
                    }
                }
                CustomSwitch {
                    id: useSensorSwitch
                    anchors.centerIn: parent
                    padding: 0
                    topPadding: coreObj.defaultLabelHeight * 0.4
                    bottomPadding: coreObj.defaultLabelHeight * 0.1
                    checked: sensorsDataObj.temperatureSensorEnabled
                    onCheckedChanged: sensorsDataObj.temperatureSensorEnabled = checked
                }
                CustomLabel {
                    id: offRowLabel
                    anchors.left: useSensorSwitch.right
                    text: qsTr("Sensor\nvalue");
                    color: 'red'
                    MouseArea {
                        anchors.fill: parent
                        onClicked: useSensorSwitch.checked = true
                    }
                }
            }

            // Changing the Pathlength value
            CustomLabel {
                id: temperatureValueLabel
                anchors.right: temperatureTextField.left                
                Layout.column: 0
                Layout.row: 1
                text: qsTr("Temperature:  ")
            }            
            CustomTextField {
                id: temperatureTextField
                Layout.column: 1
                Layout.row: 1
                implicitWidth: useSensorSwitchRowLayout.width
                text: tempDataObj.temperature
                onTextChanged: tempDataObj.temperature = text
                readOnly: sensorsDataObj.temperatureSensorEnabled  // See if this gets blocked when ReadOnly
            }            

            // ComboBox to select the pathlength units
            CustomLabel {
                id: tempUnitsLabel
                anchors.right: unitsComboBox.left                
                Layout.column: 0
                Layout.row: 2
                text: qsTr("Units:  ")
            }
            CustomComboBox {
                id: unitsComboBox
                Layout.column: 1
                Layout.row: 2
                model: [ "Kelvin, K", "Celsius, °C", "Fahrenheit, °F"]
                implicitWidth: useSensorSwitchRowLayout.width
                currentIndex: tempDataObj.units
                onCurrentIndexChanged: tempDataObj.units = currentIndex
            }            
        }
    }
}

