// bytran -|- spectral calculations for portable devices using the HITRAN database
//
// Developed by Dzianis Pliutau (Denis Plutov) and Kostya Roslyakov
// www.bytran.org | contact@bytran.org
// Copyright (c) 2016 Dzianis Pliutau
// Distributed under the MIT license
//
// The MIT License (MIT)
// Copyright (c) 2016 Dzianis Pliutau
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation
// files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy,
// modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software
// is furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
// OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR
// IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.



// QML component is used to specify the vertical scale units
import QtQuick 2.7
import QtQuick.Controls 2.0
import QtQuick.Layouts 1.0

Item {

    id: yAsisItem
    anchors.fill: parent

    // Rectangle to draw the form border
    Rectangle {
        anchors.fill: parent
        border.width: 1
        border.color: 'black'
        color: Qt.rgba(0, 0, 0, 0.6)

        // This is introduced to disable items located on the background
        MouseArea {
            anchors.fill: parent
            onClicked: { }
        }
    }

    // Rectangle to draw the form border
    Rectangle {
        anchors.fill: mainYAsisLayout
        anchors.margins: coreObj.defaultLabelHeight * (-0.85)
        color: "white"
        border.width: 1
        border.color: 'gray'
        radius: coreObj.defaultLabelHeight * 0.5
    }

    CustomLabel {
        id: widthLabel
        text: "The vertical axis scale and units"
        visible: false
        enabled: false
    }

    // Exit button
    CustomButton {
        id: exitButton
        anchors.top: yAsisItem.top
        anchors.right: yAsisItem.right
        anchors.margins: coreObj.defaultLabelHeight * (0.1)
        implicitWidth: 1.5 * exitButton.height
        text: qsTr("X")
        onClicked: {
            specResultsDataObj.updateYAxis();
            specResultsDataObj.updatePlotAllPreserveScale();
            yAsisItem.destroy();
        }
    }

    // Column layout to hold all the interface items
    ColumnLayout {

        // At rotation the buttons are not positioned exactly the way they should be (fix this)
        id: mainYAsisLayout
        anchors.centerIn: parent
        Layout.fillWidth: true
        Layout.fillHeight: true
        spacing: 3
        CustomLabel {
            Layout.fillWidth: true
            id: commentLabel
            text: qsTr("The vertical axis scale and units")
        }

        GridLayout {
            id: yAxisGridLayout
            rows: 3
            columns: 2

            // Minimum along the Y axis
            CustomLabel {
                id: minimumLabel
                anchors.right: minimumTextField.left
                Layout.column: 0
                Layout.row: 0
                text: qsTr("  Minimum:  ")
            }
            CustomTextField {
                id: minimumTextField
                Layout.fillWidth: true                
                Layout.column: 1
                Layout.row: 0                
                onTextChanged: yAxisObj.minimum = text
                text: yAxisObj.minimum
                implicitWidth: widthLabel.width - minimumLabel.width
            }

            // Maximum along the Y axis
            CustomLabel {
                id: maximumLabel
                anchors.right: maximumTextField.left
                Layout.column: 0
                Layout.row: 1
                text: qsTr("  Maximum:  ")
            }            
            CustomTextField {
                id: maximumTextField
                Layout.fillWidth: true                
                Layout.column: 1
                Layout.row: 1
                text: yAxisObj.maximum
                onTextChanged: yAxisObj.maximum = text
                implicitWidth: widthLabel.width - minimumLabel.width
            }
        }

        // Vertical axis units
        CustomComboBox  {
            id: unitsComboBox
            Layout.fillWidth: true
            implicitWidth: widthLabel.width
            model: [ "Absorption, %", "Transmission, %", "Optical depth"]
            currentIndex: yAxisObj.units
            onCurrentIndexChanged: yAxisObj.units = currentIndex
        }
    }
}

