// bytran -|- spectral calculations for portable devices using the HITRAN database
//
// Developed by Dzianis Pliutau (Denis Plutov) and Kostya Roslyakov
// www.bytran.org | contact@bytran.org
// Copyright (c) 2016 Dzianis Pliutau
// Distributed under the MIT license
//
// The US Standard atmosphere data is taken from the following report: www.dtic.mil/dtic/tr/fulltext/u2/a057506.pdf
//
// The MIT License (MIT)
// Copyright (c) 2016 Dzianis Pliutau
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation
// files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy,
// modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software
// is furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
// OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR
// IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.



// Object to contain the atmospehric model information
#ifndef ATMOSPHERE_H
#define ATMOSPHERE_H

#include "oneatmmodel.h"
#include "spectrum.h"
#include <QVector>
#include <QString>

class Atmosphere
{
public:

    Atmosphere();

    // Function to initialize the AFGL models
    void initInternalAfglModels();

    // Function to initialize the AFGL models from external files
    void initAfglModelsFromFiles();

    // Method to get and set the path to the folder with the AFGL atmospheric models
    QString getAfglModelsFolderPath();
    void setAfglModelsFolderPath(QString newModelsPath);

    // Methods to get and set the maximum number of molecules in the atmospheric model
    int getMaxNumMols();
    void setMaxNumMols(int newMaxNumMols);

    // Method to get the AFGL model by index
    OneAtmModel *getAfglModelByIndex(int index);
    OneAtmModel *getActiveAtmModel();

    // Number of the active atmospheric model
    int getAtiveAtmModelNum();
    void setActiveAtmModelNum(int newActiveAtmModelNum);

private:

    // Method to read in the entire atmospheric model from a single model directory
    void readAtmModel(QString dirPath, OneAtmModel *model);

    // Method to read in a single atmospheric profile
    void readAtmProfileFile(QString filePath, Spectrum *spec);

    // Array with the US Standard atmospehric models
    QVector<OneAtmModel> afglModels;

    // Path to the directory with the AFGL atmospheric models
    QString modelsPath;

    // Maximum number of molecules permitted in the atmosperhic model
    int maxNumMolecules;

    // Number of the active atmosperhic model
    int activeAtmModelNumber;
};

#endif // ATMOSPHERE_H
