# bytran -|- spectral calculations for portable devices using the HITRAN database
#
# Developed by Dzianis Pliutau (Denis Plutov) and Kostya Roslyakov
# www.bytran.org | contact@bytran.org
# Copyright (c) 2016 Dzianis Pliutau
# Distributed under the MIT license
#
# The MIT License (MIT)
# Copyright (c) 2016 Dzianis Pliutau
#
# Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation
# files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy,
# modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software
# is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
# OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
# LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR
# IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

QT += qml quick widgets network sensors

CONFIG += c++11

RESOURCES += qml.qrc

# Additional import path used to resolve QML modules in Qt Creator's code model
QML_IMPORT_PATH =

# Default rules for deployment.
qnx: target.path = /tmp/$${TARGET}/bin
else: unix:!android: target.path = /opt/$${TARGET}/bin
!isEmpty(target.path): INSTALLS += target

RC_ICONS = bytran.ico
ICON = bytran.icns  # the iOS specific code should be commented out for this icon to be included in the desktop, couldn't find a better solution for now

SOURCES += main.cpp \
    aboutdataobject.cpp \
    atmosphere.cpp \
    atmospheredataobject.cpp \
    auxiliary.cpp \
    bytrancore.cpp \
    colorplot.cpp \
    concpressunitsconvert.cpp \
    configinputoutput.cpp \
    const.cpp \
    custommessagebox.cpp \
    downloadregionsfinder.cpp \
    filedownloader.cpp \
    hitrandownloadoptionsdataobj.cpp \
    hitraninputoutput.cpp \
    hitranoneiso.cpp \
    hitranonemol.cpp \
    hitranonerec.cpp \
    hitranonlinedownloader.cpp \
    hitranrequestdata.cpp \
    instrumentalfunction.cpp \
    instrumentalfunctiondataobject.cpp \
    lbl.cpp \
    lineoptionsdataobject.cpp \
    mollistviewmodel.cpp \
    mollistviewreducedmodel.cpp \
    normalizeddownloadregionsfinder.cpp \
    notifierdataobject.cpp \
    oneatmmodel.cpp \
    oneisospectra.cpp \
    onelayerspectra.cpp \
    onemolspectra.cpp \
    oneslantlayer.cpp \
    params.cpp \
    pathlengthdataobject.cpp \
    pathlengthunitsconvert.cpp \
    permissions.cpp \
    plot.cpp \
    radiance.cpp \
    resultssaver.cpp \
    serverlogin.cpp \
    shareresultsdataobject.cpp \
    slant.cpp \
    spectraresultsdataobject.cpp \
    spectrum.cpp \
    temperaturedataobject.cpp \
    temperatureunitsconvert.cpp \
    tipsfilesdownloader.cpp \
    totalpressdataobject.cpp \
    wavelength.cpp \
    wavelengthdataobject.cpp \
    yaxis.cpp \
    yaxisdataobject.cpp \
    sensorsdataobject.cpp \
    humidityconvert.cpp \
    sensors.cpp

HEADERS += \
    aboutdataobject.h \
    atmosphere.h \
    atmospheredataobject.h \
    auxiliary.h \
    bytrancore.h \
    colorplot.h \
    concpressunitsconvert.h \
    configinputoutput.h \
    const.h \
    custommessagebox.h \
    downloadregionsfinder.h \
    filedownloader.h \
    hitrandownloadoptionsdataobject.h \
    hitraninputoutput.h \
    hitranoneiso.h \
    hitranonemol.h \
    hitranonerec.h \
    hitranonlinedownloader.h \
    hitranrequestdata.h \
    instrumentalfunction.h \
    instrumentalfunctiondataobj.h \
    lbl.h \
    lineoptionsdataobject.h \
    mollistviewmodel.h \
    mollistviewreducedmodel.h \
    normalizeddownloadregionsfinder.h \
    notifierdataobject.h \
    oneatmmodel.h \
    oneisospectra.h \
    onelayerspectra.h \
    onemolspectra.h \
    oneslantlayer.h \
    params.h \
    pathlengthdataobject.h \
    pathlengthunitsconvert.h \
    permissions.h \
    plot.h \
    radiance.h \
    resultssaver.h \
    serverlogin.h \
    shareresultsdataobject.h \
    slant.h \
    spectraresultsdataobject.h \
    spectrum.h \
    temperaturedataobject.h \
    temperatureunitsconvert.h \
    tipsfilesdownloader.h \
    totalpressdataobject.h \
    wavelength.h \
    wavelengthdataobject.h \
    yaxis.h \
    yaxisdataobject.h \
    sensorsdataobject.h \
    humidityconvert.h \
    sensors.h

DISTFILES += \
    android/AndroidManifest.xml \
    android/gradle/wrapper/gradle-wrapper.jar \
    android/gradlew \
    android/res/values/libs.xml \
    android/build.gradle \
    android/gradle/wrapper/gradle-wrapper.properties \
    android/gradlew.bat \
    android/libs/support-v4-23.4.0.jar \
    android/src/org/bytran/ShareIntent.java \
    android/src/org/bytran/RequestPermissions.java

android
{
    android: QT += androidextras
    ANDROID_PACKAGE_SOURCE_DIR = $$PWD/android
}

# These are for the iOS operating system to be able to share images and data
OBJECTIVE_SOURCES += ios/iosshare.mm \
    ios/iosmessagedialog.mm \
    ios/iosdefaulttextsize.mm
HEADERS += ios/iosshare.h \
    ios/iosmessagedialog.h \
    ios/iosdefaulttextsize.h

# ios icon sets etc. (when compiled for Mac the first 2 paragraphs of code should not be there as it interferes with the Mac icon)
ios
{
    QMAKE_INFO_PLIST = ios/Info.plist
    ios_icon.files = $$files($$PWD/ios-iconset/red-background/Icon*.png)
    QMAKE_BUNDLE_DATA += ios_icon

    app_launch_images.files = $$PWD/ios-launchimages/StartScreen.xib $$files($$PWD/ios-launchimages/LaunchImage*.png) $$PWD/images/bytran136.png
    QMAKE_BUNDLE_DATA += app_launch_images

    # This segment should be there for Mac as well
    Q_ENABLE_BITCODE.name = ENABLE_BITCODE
    Q_ENABLE_BITCODE.value = NO
    QMAKE_MAC_XCODE_SETTINGS += Q_ENABLE_BITCODE
}

# The approach with the slashes was used to make this work - https://bugreports.qt.io/browse/QTBUG-43468
winphone {
    WINRT_MANIFEST = $$PWD/winphone/AppxManifest.xml
    WINRT_MANIFEST.logo_44x44 = $$PWD/winphone-icons/logo_44x44.png
    WINRT_MANIFEST.logo_71x71 = $$PWD/winphone-icons/logo_71x71.png
    WINRT_MANIFEST.logo_150x150 = $$PWD/winphone-icons/logo_150x150.png
    WINRT_MANIFEST.logo_310x150 = $$PWD/winphone-icons/logo_310x150.png
    WINRT_MANIFEST.logo_480x800 = $$PWD/winphone-icons/logo_480x800.png
    WINRT_MANIFEST.logo_store = $$PWD/winphone-icons/logo_store.png
    #QMAKE_CXXFLAGS += /ZW
    #QMAKE_CXXFLAGS += /ZW /AI\"C:\Program Files (x86)\Microsoft Visual Studio 14.0\VC\vcpackages\"
}
