// bytran -|- spectral calculations for portable devices using the HITRAN database
//
// Developed by Dzianis Pliutau (Denis Plutov) and Kostya Roslyakov
// www.bytran.org | contact@bytran.org
// Copyright (c) 2016 Dzianis Pliutau
// Distributed under the MIT license
//
// Parts of the line-by-line calculation algorithm are based on the Python code from the HITRAN Application Programming Interface (HAPI)
// R.V. Kochanov, I.E. Gordon, L.S. Rothman, P. Wcisło, C. Hill, J.S. Wilzewski, "HITRAN Application Programming Interface (HAPI):
// A comprehensive approach to working with spectroscopic data", JQSRT, Volume 177, July 2016, Pages 15–30; (hitran.org/hapi/)
//
// The MIT License (MIT)
// Copyright (c) 2016 Dzianis Pliutau
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation
// files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy,
// modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software
// is furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
// OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR
// IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.



// Class containing constants to be used in calculations
#ifndef CONST_H
#define CONST_H

class Const
{
public:
    Const();

public:

    // Physical constants
    static const double BoltsCgs;  // Boltzman constant (CGS units)
    static const double Bolts;     // Boltzman constant (SI units)
    static const double cCgs;   // Speed of light constant (CGS units)
    static const double c;      // Speed of light constant (SI units)
    static const double hCgs;   // Plank's constant (in CGS units)
    static const double pi;     // Value of Pi
    static const double Loch;   // Lochmidts number
    static const double c2;     // c2 - second black body radiation constant

    // Reference temperature and pressure values
    static const double tempRef;        // Reference temperature, Kelvin
    static const double totalPressRef;  // Reference pressure, Atm

    // Constant used to calcualte the molecular mass, this value is equal to (1 / Navogadro) * 10E-3
    static const double cMassMol;

    // Computational constants
    static const double sqrt2Ln2;          // sqrt(2 * ln(2))
    static const double sqrtLn2divSqrtPi;  // sqrt(ln(2) / Pi)
    static const double ln2;               // ln(2)
    static const double sqrtLn2;           // sqrt(ln(2))
};

#endif // CONST_H
