// bytran -|- spectral calculations for portable devices using the HITRAN database
//
// Developed by Dzianis Pliutau (Denis Plutov) and Kostya Roslyakov
// www.bytran.org | contact@bytran.org
// Copyright (c) 2016 Dzianis Pliutau
// Distributed under the MIT license
//
// The MIT License (MIT)
// Copyright (c) 2016 Dzianis Pliutau
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation
// files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy,
// modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software
// is furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
// OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR
// IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.



// Object for a single HITRAN molecule
#ifndef HITRANONEMOL_H
#define HITRANONEMOL_H

#include <QVector>
#include <QString>
#include "hitranoneiso.h"

class HitranOneMol
{
public:

    HitranOneMol();

    // Array of type hitranOneIsoObj to contain information for each isotope
    QVector<HitranOneIso> *getIso();
    void setIso(QVector<HitranOneIso> *newIso);
    HitranOneIso *getIsoAt(int index);
    void setIsoAt(int index,  HitranOneIso *iso);

    // Name of the molecule
    QString getMolName();
    void setMolName(QString newMolName);

    // Molecule chemical formula
    QString getChemForm();
    void setChemForm(QString newChemForm);

    // Variable indicating if the molecule is selected for calculation (1 - selected, 0 - not selected)
    bool getSelected();
    void setSelected(bool newSelected);

    // Color to use for plotting a given isotope
    QString getColor();
    void setColor(QString newColor);

private:

    QVector<HitranOneIso> iso;  // Array of type hitranOneIsoObj to contain information for each isotope

    QString molName;   // Name of the molecule
    QString chemForm;  // Molecule chemical formula
    bool selected;  // Variable indicating if the molecule is selected for calculation (1 - selected, 0 - not selected)
    QString color;  // Color to use for plotting a given isotope

};

#endif // HITRANONEMOL_H
