// bytran -|- spectral calculations for portable devices using the HITRAN database// "bytran" - Program to calculate the transmission of gases and atmosphere using the HITRAN database (hitran.org)
//
// Developed by Dzianis Pliutau (Denis Plutov) and Kostya Roslyakov
// www.bytran.org | contact@bytran.org
// Copyright (c) 2016 Dzianis Pliutau
// Distributed under the MIT license
//
// The MIT License (MIT)
// Copyright (c) 2016 Dzianis Pliutau
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation
// files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy,
// modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software
// is furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
// OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR
// IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.



// Object to containing information about a single atmospheric model
#ifndef ONEATMMODEL_H
#define ONEATMMODEL_H

#include <QVector>
#include <QString>
#include <spectrum.h>

class OneAtmModel
{
public:

    OneAtmModel();

    // Getting and setting the atmospheric model parameters
    Spectrum *getTotalPress();
    void setTotalPress(Spectrum *newTotalPress);
    Spectrum *getTemp();
    void setTemp(Spectrum *newTemp);
    Spectrum *getDensity();
    void setDensity(Spectrum *newDensity);

    // Getting and setting the partial pressure
    QVector<Spectrum> *getPartPressArray();
    Spectrum *getPartPressSpecByMolIndex(int molIndex);
    void setPartPressSpecByMolIndex(int molIndex, Spectrum *partPressSpec);
    void resizePartPressArray(int newSize);

    // Method to append a new partial pressure spectrum (for a given molecule) to the array of partial pressure spectra
    void appendPartPress(Spectrum *newPartPressSpec);

    // Method to get the number of molecules in the model
    int getNumMolecules();

    // Getting and setting the model name
    QString getModelName();
    void setModelName(QString newModelName);

private:

    // Total pressure, temperature and density
    Spectrum totalPress;
    Spectrum temp;
    Spectrum density;

    // Partial pressures
    QVector<Spectrum> partPress;

    // Model name
    QString modelName;
};

#endif // ONEATMMODEL_H
