// bytran -|- spectral calculations for portable devices using the HITRAN database
//
// Developed by Dzianis Pliutau (Denis Plutov) and Kostya Roslyakov
// www.bytran.org | contact@bytran.org
// Copyright (c) 2016 Dzianis Pliutau
// Distributed under the MIT license
//
// The MIT License (MIT)
// Copyright (c) 2016 Dzianis Pliutau
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation
// files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy,
// modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software
// is furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
// OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR
// IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.



// Object containing parameters for a single slant path layer
#include "oneslantlayer.h"
#include <QMessageBox>


OneSlantLayer::OneSlantLayer()
{
}

// Getting and setting the total pressure for a layer
double OneSlantLayer::getTotalPress() { return this->totalPress; }
void OneSlantLayer::setTotalPress(double newTotalPress) { this->totalPress = newTotalPress; }

// Getting and setting the temperature within a layer
double OneSlantLayer::getTemp() { return this->temp; }
void OneSlantLayer::setTemp(double newTemp) { this->temp = newTemp; }

// Getting and setting the density within a layer
double OneSlantLayer::getDensity() { return this->density; }
void OneSlantLayer::setDensity(double newDensity) { this->density = newDensity; }

// Getting and setting the partial pressure
QVector<double> *OneSlantLayer::getPartPressArray() { return &(this->partPress); }
void OneSlantLayer::setPartPressArray(QVector<double> *newPartPressArray) { this->partPress = *newPartPressArray; }
double OneSlantLayer::getPartPress(int molIndex) { return this->partPress[molIndex]; }
void OneSlantLayer::setPartPress(int molIndex,  double partPressValue) { this->partPress[molIndex] = partPressValue; }
void OneSlantLayer::resizePartPress(int newSize) { partPress.resize(newSize); }

// Methods to get and set the slant path layer path value
double OneSlantLayer::getPathLength() { return this->pathLength; }
void OneSlantLayer::setPathLength(double newPathLength) { this->pathLength = newPathLength; }

// Method to get and set the slant path layer refractive index value
double OneSlantLayer::getRefrIndexValue() { return this->refrIndex; }
void OneSlantLayer::setRefrIndexValue(double newRefrIndex) { this->refrIndex = newRefrIndex; }
