// bytran -|- spectral calculations for portable devices using the HITRAN database
//
// Developed by Dzianis Pliutau (Denis Plutov) and Kostya Roslyakov
// www.bytran.org | contact@bytran.org
// Copyright (c) 2016 Dzianis Pliutau
// Distributed under the MIT license
//
// The MIT License (MIT)
// Copyright (c) 2016 Dzianis Pliutau
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation
// files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy,
// modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software
// is furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
// OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR
// IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.



// Object is used to relay the pathlength information betweeen the C++ data objects and the QML interface
#ifndef PATHLENGTHDATAOBJECT_H
#define PATHLENGTHDATAOBJECT_H

#include <QObject>
#include <QLocale>
#include "bytrancore.h"

class PathlengthDataObject : public QObject
{
    Q_OBJECT    

    Q_PROPERTY(QString pathlength READ pathlength WRITE setPathlength NOTIFY pathlengthChanged)
    Q_PROPERTY(int units READ units WRITE setUnits NOTIFY unitsChanged)

public:

    explicit PathlengthDataObject(QObject *parent = 0, BytranCore *inCore = 0);
    PathlengthDataObject(const QString &pathlength, const int &units, QObject *parent=0);

    QString pathlength() const;
    void setPathlength(const QString &pathlength);

    int units() const;
    void setUnits(const int &units);

signals:

    void pathlengthChanged();
    void unitsChanged();

private:

    QString m_pathlength;
    int m_units;

    // Core object with the calculation logic etc.
    BytranCore *core;

    // Locale specific string to number and inverse conversions
    QLocale loc;

};

#endif // PATHLENGTHDATAOBJECT_H
