// bytran -|- spectral calculations for portable devices using the HITRAN database
//
// Developed by Dzianis Pliutau (Denis Plutov) and Kostya Roslyakov
// www.bytran.org | contact@bytran.org
// Copyright (c) 2016 Dzianis Pliutau
// Distributed under the MIT license
//
// The MIT License (MIT)
// Copyright (c) 2016 Dzianis Pliutau
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation
// files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy,
// modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software
// is furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
// OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR
// IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.



// Object stores the currently active temperature units and performs conversions from / to the default units to the currently active temperature units
#ifndef TEMPERATUREUNITSCONVERT_H
#define TEMPERATUREUNITSCONVERT_H

#include <QString>

class TemperatureUnitsConvert
{
public:

    TemperatureUnitsConvert();

    // Method to get and set the current temperature units
    int getUnits();
    void setUnits(int newUnits);

    // Method to get the abbreviated units string for the current units index
    QString getCurrTempUnitsAbbrevStr();

    // Method to convert from default units to current units
    double fromDefaultToCurrent(double defaultValue);

    // Method to convert from the current units to the default units
    double fromCurrentToDefault(double currentValue);

    // Method to convert from specified units to current units
    double fromSpecifiedToCurrent(int fromUnits, double fromValue);

    // Method will convert temperature from the default units to the specified units
    double fromDefaultToSpecified(int toUnits, double fromValue);

private:

    int currentUnits;  // 0 - Kelvin, K;  1 - Celsius, C;  2 - Fahrenheit, F

};

#endif // TEMPERATUREUNITSCONVERT_H
